@@ -444,7 +444,7 @@ e_cell_combo_show_popup (ECellCombo *ecc,
 	gtk_widget_show (ecc->popup_window);
 
 	e_cell_popup_set_shown (E_CELL_POPUP (ecc), TRUE);
-	d (g_print ("%s: popup_shown = TRUE\n", __FUNCTION__));
+	d (g_print ("%s: popup_shown = TRUE\n", G_STRFUNC));
 }
 
 /* Calculates the size and position of the popup window (like GtkCombo). */
@@ -668,7 +668,7 @@ e_cell_combo_button_press (GtkWidget *popup_window,
 	gtk_widget_hide (ecc->popup_window);
 
 	e_cell_popup_set_shown (E_CELL_POPUP (ecc), FALSE);
-	d (g_print ("%s: popup_shown = FALSE\n", __FUNCTION__));
+	d (g_print ("%s: popup_shown = FALSE\n", G_STRFUNC));
 
 	/* We don't want to update the cell here. Since the list is in browse
 	 * mode there will always be one item selected, so when we popup the
@@ -723,7 +723,7 @@ e_cell_combo_button_release (GtkWidget *popup_window,
 	gtk_widget_hide (ecc->popup_window);
 
 	e_cell_popup_set_shown (E_CELL_POPUP (ecc), FALSE);
-	d (g_print ("%s: popup_shown = FALSE\n", __FUNCTION__));
+	d (g_print ("%s: popup_shown = FALSE\n", G_STRFUNC));
 
 	e_cell_combo_update_cell (ecc);
 	e_cell_combo_restart_edit (ecc);
@@ -773,7 +773,7 @@ e_cell_combo_key_press (GtkWidget *popup_window,
 	gtk_widget_hide (ecc->popup_window);
 
 	e_cell_popup_set_shown (E_CELL_POPUP (ecc), FALSE);
-	d (g_print ("%s: popup_shown = FALSE\n", __FUNCTION__));
+	d (g_print ("%s: popup_shown = FALSE\n", G_STRFUNC));
 
 	if (event_keyval != GDK_KEY_Escape)
 		e_cell_combo_update_cell (ecc);
