@@ -110,6 +110,9 @@ G_DEFINE_TYPE (
 	e_cell_renderer_safe_toggle,
 	GTK_TYPE_CELL_RENDERER_TOGGLE)
 
+static void selection_changed_callback (GtkTreeSelection *selection,
+					ESourceSelector *selector);
+
 static gboolean
 safe_toggle_activate (GtkCellRenderer *cell,
                       GdkEvent *event,
@@ -342,6 +345,7 @@ source_selector_build_model (ESourceSelector *selector)
 	GQueue queue = G_QUEUE_INIT;
 	GHashTable *source_index;
 	GtkTreeView *tree_view;
+	GtkTreeSelection *selection;
 	GtkTreeModel *model;
 	ESource *selected;
 	const gchar *extension_name;
@@ -359,6 +363,12 @@ source_selector_build_model (ESourceSelector *selector)
 
 	source_index = selector->priv->source_index;
 	selected = e_source_selector_ref_primary_selection (selector);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (selector));
+
+	/* Signal is blocked to avoid "primary-selection-changed" signal on model clear */
+	g_signal_handlers_block_matched (
+		selection, G_SIGNAL_MATCH_FUNC,
+		0, 0, NULL, selection_changed_callback, NULL);
 
 	/* Save expanded sources to restore later. */
 	gtk_tree_view_map_expanded_rows (
@@ -404,6 +414,12 @@ source_selector_build_model (ESourceSelector *selector)
 		g_object_unref (selected);
 	}
 
+	/* If the first succeeded, then there is no selection change, thus no need
+	   for notification; notify about the change in ay other cases */
+	g_signal_handlers_unblock_matched (
+		selection, G_SIGNAL_MATCH_FUNC,
+		0, 0, NULL, selection_changed_callback, NULL);
+
 	/* Make sure we have a primary selection.  If not, pick one. */
 	selected = e_source_selector_ref_primary_selection (selector);
 	if (selected == NULL) {
@@ -445,6 +461,12 @@ source_selector_source_added_cb (ESourceRegistry *registry,
                                  ESource *source,
                                  ESourceSelector *selector)
 {
+	const gchar *extension_name;
+
+	extension_name = e_source_selector_get_extension_name (selector);
+	if (!extension_name || !e_source_has_extension (source, extension_name))
+		return;
+
 	source_selector_build_model (selector);
 
 	source_selector_expand_to_source (selector, source);
@@ -455,6 +477,12 @@ source_selector_source_changed_cb (ESourceRegistry *registry,
                                    ESource *source,
                                    ESourceSelector *selector)
 {
+	const gchar *extension_name;
+
+	extension_name = e_source_selector_get_extension_name (selector);
+	if (!extension_name || !e_source_has_extension (source, extension_name))
+		return;
+
 	source_selector_cancel_write (selector, source);
 
 	e_source_selector_update_row (selector, source);
@@ -465,6 +493,12 @@ source_selector_source_removed_cb (ESourceRegistry *registry,
                                    ESource *source,
                                    ESourceSelector *selector)
 {
+	const gchar *extension_name;
+
+	extension_name = e_source_selector_get_extension_name (selector);
+	if (!extension_name || !e_source_has_extension (source, extension_name))
+		return;
+
 	source_selector_build_model (selector);
 }
 
@@ -473,6 +507,12 @@ source_selector_source_enabled_cb (ESourceRegistry *registry,
                                    ESource *source,
                                    ESourceSelector *selector)
 {
+	const gchar *extension_name;
+
+	extension_name = e_source_selector_get_extension_name (selector);
+	if (!extension_name || !e_source_has_extension (source, extension_name))
+		return;
+
 	source_selector_build_model (selector);
 
 	source_selector_expand_to_source (selector, source);
@@ -483,6 +523,12 @@ source_selector_source_disabled_cb (ESourceRegistry *registry,
                                     ESource *source,
                                     ESourceSelector *selector)
 {
+	const gchar *extension_name;
+
+	extension_name = e_source_selector_get_extension_name (selector);
+	if (!extension_name || !e_source_has_extension (source, extension_name))
+		return;
+
 	source_selector_build_model (selector);
 }
 
@@ -856,7 +902,7 @@ source_selector_button_press_event (GtkWidget *widget,
 {
 	ESourceSelector *selector;
 	GtkWidgetClass *widget_class;
-	GtkTreePath *path;
+	GtkTreePath *path = NULL;
 	ESource *source = NULL;
 	ESource *primary;
 	gboolean right_click = FALSE;
@@ -892,6 +938,9 @@ source_selector_button_press_event (GtkWidget *widget,
 		gtk_tree_model_get (model, &iter, COLUMN_SOURCE, &source, -1);
 	}
 
+	if (path)
+		gtk_tree_path_free (path);
+
 	if (source == NULL)
 		goto chainup;
 
