@@ -108,6 +108,30 @@ mail_backend_uri_to_evname (const gchar *uri,
 	return filename;
 }
 
+static gboolean
+mail_backend_any_store_requires_downsync (EMailAccountStore *account_store)
+{
+	GQueue queue = G_QUEUE_INIT;
+	gboolean any_requires_downsync = FALSE;
+
+	g_return_val_if_fail (E_IS_MAIL_ACCOUNT_STORE (account_store), FALSE);
+
+	e_mail_account_store_queue_enabled_services (account_store, &queue);
+	while (!g_queue_is_empty (&queue)) {
+		CamelService *service;
+
+		service = g_queue_pop_head (&queue);
+		if (service == NULL)
+			continue;
+
+		if (CAMEL_IS_OFFLINE_STORE (service))
+			any_requires_downsync = any_requires_downsync ||
+				camel_offline_store_requires_downsync (CAMEL_OFFLINE_STORE (service));
+	}
+
+	return any_requires_downsync;
+}
+
 /* Callback for various asynchronous CamelStore operations where
  * the EActivity's reference count is used as a counting semaphore. */
 static void
@@ -122,6 +146,24 @@ mail_backend_store_operation_done_cb (CamelStore *store,
 	g_object_unref (activity);
 }
 
+static void
+mail_backend_local_trash_expunge_done_cb (GObject *source_object,
+					  GAsyncResult *result,
+					  gpointer user_data)
+{
+	CamelFolder *folder = CAMEL_FOLDER (source_object);
+	EActivity *activity = user_data;
+	GError *error = NULL;
+
+	if (!e_mail_folder_expunge_finish (folder, result, &error)) {
+		g_warning ("%s: Failed to expunge local trash: %s", G_STRFUNC, error ? error->message : "Unknown error");
+	}
+
+	g_clear_error (&error);
+
+	g_object_unref (activity);
+}
+
 static void
 mail_backend_set_session_offline_cb (gpointer user_data,
 				     GObject *object)
@@ -157,12 +199,15 @@ mail_backend_prepare_for_offline_cb (EShell *shell,
 	if (e_shell_backend_is_started (shell_backend)) {
 		gboolean synchronize = FALSE;
 
-		if (e_shell_get_network_available (shell))
+		if (e_shell_get_network_available (shell) &&
+		    mail_backend_any_store_requires_downsync (account_store))
 			synchronize = em_utils_prompt_user (
 				window, NULL, "mail:ask-quick-offline", NULL);
 
-		if (synchronize)
+		if (!synchronize) {
 			e_shell_backend_cancel_all (shell_backend);
+			camel_session_set_online (CAMEL_SESSION (session), FALSE);
+		}
 
 		if (!e_activity_get_cancellable (activity)) {
 			GCancellable *cancellable;
@@ -347,14 +392,33 @@ mail_backend_prepare_for_quit_cb (EShell *shell,
 		    !mail_backend_service_is_enabled (registry, service))
 			continue;
 
-		/* FIXME Not passing a GCancellable. */
-		/* FIXME This operation should be queued. */
-		camel_store_synchronize (
-			CAMEL_STORE (service),
-			empty_trash, G_PRIORITY_DEFAULT,
-			NULL, (GAsyncReadyCallback)
-			mail_backend_store_operation_done_cb,
-			g_object_ref (activity));
+		if (empty_trash && g_strcmp0 (camel_service_get_uid (service), E_MAIL_SESSION_LOCAL_UID) == 0) {
+			/* local trash requires special handling,
+			   due to POP3's "delete-expunged" option */
+			CamelFolder *local_trash;
+			GCancellable *cancellable = e_activity_get_cancellable (activity);
+
+			/* This should be lightning-fast, it's a local trash folder */
+			local_trash = camel_store_get_trash_folder_sync (CAMEL_STORE (service), cancellable, NULL);
+
+			if (local_trash) {
+				e_mail_folder_expunge (local_trash,
+					G_PRIORITY_DEFAULT, cancellable,
+					mail_backend_local_trash_expunge_done_cb,
+					g_object_ref (activity));
+
+				g_object_unref (local_trash);
+			}
+		} else {
+			/* FIXME Not passing a GCancellable. */
+			/* FIXME This operation should be queued. */
+			camel_store_synchronize (
+				CAMEL_STORE (service),
+				empty_trash, G_PRIORITY_DEFAULT,
+				NULL, (GAsyncReadyCallback)
+				mail_backend_store_operation_done_cb,
+				g_object_ref (activity));
+		}
 	}
 
 	g_list_free_full (list, (GDestroyNotify) g_object_unref);
